@@ -1,15 +1,15 @@
 '''See http://pythonhosted.org/psycopg2/advanced.html'''
 import binascii
 import psycopg2
-from psycopg2.extensions import AsIs, ISQLQuote, new_type, register_type
+from psycopg2.extensions import AsIs, ISQLQuote, new_type, \
+                                register_type, register_adapter
 
 try:
     import cPickles as pickle
 except ImportError:
     import pickle
 
-from . import Cucumber
-
+from . import cucumber_add_ons
 
 postgres_type = None
 
@@ -31,19 +31,23 @@ def cast_bytea(value, cur):
         raise InterfaceError('bad bytea representation: {!r}'.format(value))
 
 
-def __conform__(self, protocol):
-    '''Indicate that this object can be conformed to SQL by getquoted().'''
-    if protocol == ISQLQuote:
-        return self
+def add_adapter(cls):
+    '''Register adapt_bytea() with this class.'''
+    register_adapter(cls, adapt_bytea) 
+    return cls
 
 
-def getquoted(self):
+def adapt_bytea(obj):
+    '''Adapt an object using getquoted().'''
+    return AsIs(getquoted(obj))
+
+
+def getquoted(obj):
     '''Cast a python value to an SQL bytea through pickling.'''
-    p = pickle.dumps(self, pickle.HIGHEST_PROTOCOL)
+    p = pickle.dumps(obj, pickle.HIGHEST_PROTOCOL)
     bytea = "E'\\\\x{0}'::bytea".format(binascii.hexlify(p))
     return bytea
 
 
-# Add __conform__ and getquoted to Cucumber.
-Cucumber.__conform__ = __conform__
-Cucumber.getquoted = getquoted
+# Add __conform__ and getquoted to the methods added to cucumbers.
+cucumber_add_ons.append(add_adapter)
